==> duckdb_0.3.2.tar.gz: duckdb/src/duckdb/amalgamation-17.cpp <==
#include "src/planner/expression_binder/insert_binder.cpp"

#include "src/planner/expression_binder/order_binder.cpp"

#include "src/planner/expression_binder/qualify_binder.cpp"

#include "src/planner/expression_binder/relation_binder.cpp"

#include "src/planner/expression_binder/select_binder.cpp"

#include "src/planner/expression_binder/update_binder.cpp"

#include "src/planner/expression_binder/where_binder.cpp"

#include "src/planner/expression_iterator.cpp"

#include "src/planner/filter/conjunction_filter.cpp"

#include "src/planner/filter/constant_filter.cpp"

#include "src/planner/filter/null_filter.cpp"

#include "src/planner/joinside.cpp"

#include "src/planner/logical_operator.cpp"

#include "src/planner/logical_operator_visitor.cpp"

#include "src/planner/operator/logical_aggregate.cpp"

#include "src/planner/operator/logical_any_join.cpp"

#include "src/planner/operator/logical_comparison_join.cpp"

#include "src/planner/operator/logical_cross_product.cpp"

#include "src/planner/operator/logical_distinct.cpp"

#include "src/planner/operator/logical_empty_result.cpp"

#include "src/planner/operator/logical_filter.cpp"

#include "src/planner/operator/logical_get.cpp"

#include "src/planner/operator/logical_join.cpp"

#include "src/planner/operator/logical_limit.cpp"

#include "src/planner/operator/logical_projection.cpp"

#include "src/planner/operator/logical_sample.cpp"

#include "src/planner/operator/logical_unnest.cpp"

#include "src/planner/operator/logical_window.cpp"

#include "src/planner/planner.cpp"

#include "src/planner/pragma_handler.cpp"

#include "src/planner/subquery/flatten_dependent_join.cpp"

#include "src/planner/subquery/has_correlated_expressions.cpp"

#include "src/planner/subquery/rewrite_correlated_expressions.cpp"

#include "src/planner/table_binding.cpp"

#include "src/planner/table_filter.cpp"

#include "src/storage/block.cpp"

#include "src/storage/buffer/buffer_handle.cpp"

#include "src/storage/buffer/managed_buffer.cpp"

#include "src/storage/buffer_manager.cpp"

#include "src/storage/checkpoint/table_data_reader.cpp"

#include "src/storage/checkpoint/table_data_writer.cpp"

#include "src/storage/checkpoint/write_overflow_strings_to_disk.cpp"

#include "src/storage/checkpoint_manager.cpp"

#include "src/storage/compression/bitpacking.cpp"

#include "src/storage/compression/fixed_size_uncompressed.cpp"

#include "src/storage/compression/numeric_constant.cpp"

==> duckdb_0.3.4.tar.gz: duckdb/src/duckdb/amalgamation-17.cpp <==
#include "src/planner/expression_binder/having_binder.cpp"

#include "src/planner/expression_binder/index_binder.cpp"

#include "src/planner/expression_binder/insert_binder.cpp"

#include "src/planner/expression_binder/order_binder.cpp"

#include "src/planner/expression_binder/qualify_binder.cpp"

#include "src/planner/expression_binder/relation_binder.cpp"

#include "src/planner/expression_binder/returning_binder.cpp"

#include "src/planner/expression_binder/select_binder.cpp"

#include "src/planner/expression_binder/update_binder.cpp"

#include "src/planner/expression_binder/where_binder.cpp"

#include "src/planner/expression_iterator.cpp"

#include "src/planner/filter/conjunction_filter.cpp"

#include "src/planner/filter/constant_filter.cpp"

#include "src/planner/filter/null_filter.cpp"

#include "src/planner/joinside.cpp"

#include "src/planner/logical_operator.cpp"

#include "src/planner/logical_operator_visitor.cpp"

#include "src/planner/operator/logical_aggregate.cpp"

#include "src/planner/operator/logical_any_join.cpp"

#include "src/planner/operator/logical_comparison_join.cpp"

#include "src/planner/operator/logical_cross_product.cpp"

#include "src/planner/operator/logical_distinct.cpp"

#include "src/planner/operator/logical_empty_result.cpp"

#include "src/planner/operator/logical_filter.cpp"

#include "src/planner/operator/logical_get.cpp"

#include "src/planner/operator/logical_join.cpp"

#include "src/planner/operator/logical_limit.cpp"

#include "src/planner/operator/logical_projection.cpp"

#include "src/planner/operator/logical_sample.cpp"

#include "src/planner/operator/logical_unnest.cpp"

#include "src/planner/operator/logical_window.cpp"

#include "src/planner/planner.cpp"

#include "src/planner/pragma_handler.cpp"

#include "src/planner/subquery/flatten_dependent_join.cpp"

#include "src/planner/subquery/has_correlated_expressions.cpp"

#include "src/planner/subquery/rewrite_correlated_expressions.cpp"

#include "src/planner/table_binding.cpp"

#include "src/planner/table_filter.cpp"

#include "src/storage/block.cpp"

#include "src/storage/buffer/buffer_handle.cpp"

#include "src/storage/buffer/managed_buffer.cpp"

#include "src/storage/buffer_manager.cpp"

#include "src/storage/checkpoint/table_data_reader.cpp"

#include "src/storage/checkpoint/table_data_writer.cpp"

#include "src/storage/checkpoint/write_overflow_strings_to_disk.cpp"

#include "src/storage/checkpoint_manager.cpp"

#include "src/storage/compression/bitpacking.cpp"
